==> root-debug-6.36.04-6-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/montecarlo/pythia8/G__EGPythia8.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__EGPythia8
#define R__NO_DEPRECATION

/*******************************************************************/
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "TPythia8.h"
#include "TPythia8Decayer.h"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   static void *new_TPythia8(void *p = nullptr);
   static void *newArray_TPythia8(Long_t size, void *p);
   static void delete_TPythia8(void *p);
   static void deleteArray_TPythia8(void *p);
   static void destruct_TPythia8(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TPythia8*)
   {
      ::TPythia8 *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TPythia8 >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TPythia8", ::TPythia8::Class_Version(), "TPythia8.h", 76,
                  typeid(::TPythia8), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TPythia8::Dictionary, isa_proxy, 4,
                  sizeof(::TPythia8) );
      instance.SetNew(&new_TPythia8);
      instance.SetNewArray(&newArray_TPythia8);
      instance.SetDelete(&delete_TPythia8);
      instance.SetDeleteArray(&deleteArray_TPythia8);
      instance.SetDestructor(&destruct_TPythia8);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TPythia8*)
   {
      return GenerateInitInstanceLocal(static_cast<::TPythia8*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TPythia8*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

namespace ROOT {
   static void *new_TPythia8Decayer(void *p = nullptr);
   static void *newArray_TPythia8Decayer(Long_t size, void *p);
   static void delete_TPythia8Decayer(void *p);
   static void deleteArray_TPythia8Decayer(void *p);
   static void destruct_TPythia8Decayer(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TPythia8Decayer*)
   {
      ::TPythia8Decayer *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TPythia8Decayer >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TPythia8Decayer", ::TPythia8Decayer::Class_Version(), "TPythia8Decayer.h", 21,
                  typeid(::TPythia8Decayer), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TPythia8Decayer::Dictionary, isa_proxy, 4,
                  sizeof(::TPythia8Decayer) );
      instance.SetNew(&new_TPythia8Decayer);
      instance.SetNewArray(&newArray_TPythia8Decayer);
      instance.SetDelete(&delete_TPythia8Decayer);
      instance.SetDeleteArray(&deleteArray_TPythia8Decayer);
      instance.SetDestructor(&destruct_TPythia8Decayer);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TPythia8Decayer*)
   {
      return GenerateInitInstanceLocal(static_cast<::TPythia8Decayer*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TPythia8Decayer*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

//______________________________________________________________________________
atomic_TClass_ptr TPythia8::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TPythia8::Class_Name()
{
   return "TPythia8";
}

//______________________________________________________________________________
const char *TPythia8::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TPythia8*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TPythia8::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TPythia8*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TPythia8::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TPythia8*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TPythia8::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TPythia8*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
atomic_TClass_ptr TPythia8Decayer::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TPythia8Decayer::Class_Name()
{
   return "TPythia8Decayer";
}

//______________________________________________________________________________
const char *TPythia8Decayer::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TPythia8Decayer*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TPythia8Decayer::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TPythia8Decayer*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TPythia8Decayer::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TPythia8Decayer*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TPythia8Decayer::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TPythia8Decayer*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
void TPythia8::Streamer(TBuffer &R__b)
{
   // Stream an object of class TPythia8.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TPythia8::Class(),this);
   } else {
      R__b.WriteClassBuffer(TPythia8::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TPythia8(void *p) {
      return  p ? new(p) ::TPythia8 : new ::TPythia8;
   }
   static void *newArray_TPythia8(Long_t nElements, void *p) {
      return p ? new(p) ::TPythia8[nElements] : new ::TPythia8[nElements];
   }
   // Wrapper around operator delete
   static void delete_TPythia8(void *p) {
      delete (static_cast<::TPythia8*>(p));
   }
   static void deleteArray_TPythia8(void *p) {
      delete [] (static_cast<::TPythia8*>(p));
   }
   static void destruct_TPythia8(void *p) {
      typedef ::TPythia8 current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TPythia8

//______________________________________________________________________________
void TPythia8Decayer::Streamer(TBuffer &R__b)
{
   // Stream an object of class TPythia8Decayer.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TPythia8Decayer::Class(),this);
   } else {
      R__b.WriteClassBuffer(TPythia8Decayer::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TPythia8Decayer(void *p) {
      return  p ? new(p) ::TPythia8Decayer : new ::TPythia8Decayer;
   }
   static void *newArray_TPythia8Decayer(Long_t nElements, void *p) {
      return p ? new(p) ::TPythia8Decayer[nElements] : new ::TPythia8Decayer[nElements];
   }
   // Wrapper around operator delete
   static void delete_TPythia8Decayer(void *p) {
      delete (static_cast<::TPythia8Decayer*>(p));
   }
   static void deleteArray_TPythia8Decayer(void *p) {
      delete [] (static_cast<::TPythia8Decayer*>(p));
   }
   static void destruct_TPythia8Decayer(void *p) {
      typedef ::TPythia8Decayer current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TPythia8Decayer

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libEGPythia8() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libEGPythia8) = RecordReadRules_libEGPythia8();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libEGPythia8));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libEGPythia8_Impl() {
    static const char* headers[] = {
"TPythia8.h",
"TPythia8Decayer.h",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/usr/include/freetype2",
"/usr/include",
"/usr/include/freetype2",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = R"DICTFWDDCLS(
#line 1 "libEGPythia8 dictionary forward declarations' payload"
#pragma clang diagnostic ignored "-Wkeyword-compat"
#pragma clang diagnostic ignored "-Wignored-attributes"
#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
extern int __Cling_AutoLoading_Map;
class __attribute__((annotate("$clingAutoload$TPythia8.h")))  TPythia8;
class __attribute__((annotate("$clingAutoload$TPythia8Decayer.h")))  TPythia8Decayer;
)DICTFWDDCLS";
    static const char* payloadCode = R"DICTPAYLOAD(
#line 1 "libEGPythia8 dictionary payload"

#ifndef ROOT_SUPPORT_CLAD
  #define ROOT_SUPPORT_CLAD 1
#endif

#define _BACKWARD_BACKWARD_WARNING_H
// Inline headers
#include "TPythia8.h"
#include "TPythia8Decayer.h"

#undef  _BACKWARD_BACKWARD_WARNING_H
)DICTPAYLOAD";
    static const char* classesHeaders[] = {
"TPythia8", payloadCode, "@",
"TPythia8Decayer", payloadCode, "@",
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libEGPythia8",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libEGPythia8_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libEGPythia8_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libEGPythia8() {
  TriggerDictionaryInitialization_libEGPythia8_Impl();
}

==> root-debug-6.38.00-3-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/montecarlo/pythia8/G__EGPythia8.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__EGPythia8
#define R__NO_DEPRECATION

/*******************************************************************/
#include <cstddef>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "TPythia8.h"
#include "TPythia8Decayer.h"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   static void *new_TPythia8(void *p = nullptr);
   static void *newArray_TPythia8(Long_t size, void *p);
   static void delete_TPythia8(void *p);
   static void deleteArray_TPythia8(void *p);
   static void destruct_TPythia8(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TPythia8*)
   {
      ::TPythia8 *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TPythia8 >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TPythia8", ::TPythia8::Class_Version(), "TPythia8.h", 76,
                  typeid(::TPythia8), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TPythia8::Dictionary, isa_proxy, 4,
                  sizeof(::TPythia8) );
      instance.SetNew(&new_TPythia8);
      instance.SetNewArray(&newArray_TPythia8);
      instance.SetDelete(&delete_TPythia8);
      instance.SetDeleteArray(&deleteArray_TPythia8);
      instance.SetDestructor(&destruct_TPythia8);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TPythia8*)
   {
      return GenerateInitInstanceLocal(static_cast<::TPythia8*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TPythia8*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

namespace ROOT {
   static void *new_TPythia8Decayer(void *p = nullptr);
   static void *newArray_TPythia8Decayer(Long_t size, void *p);
   static void delete_TPythia8Decayer(void *p);
   static void deleteArray_TPythia8Decayer(void *p);
   static void destruct_TPythia8Decayer(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TPythia8Decayer*)
   {
      ::TPythia8Decayer *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TPythia8Decayer >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TPythia8Decayer", ::TPythia8Decayer::Class_Version(), "TPythia8Decayer.h", 21,
                  typeid(::TPythia8Decayer), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TPythia8Decayer::Dictionary, isa_proxy, 4,
                  sizeof(::TPythia8Decayer) );
      instance.SetNew(&new_TPythia8Decayer);
      instance.SetNewArray(&newArray_TPythia8Decayer);
      instance.SetDelete(&delete_TPythia8Decayer);
      instance.SetDeleteArray(&deleteArray_TPythia8Decayer);
      instance.SetDestructor(&destruct_TPythia8Decayer);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TPythia8Decayer*)
   {
      return GenerateInitInstanceLocal(static_cast<::TPythia8Decayer*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TPythia8Decayer*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

//______________________________________________________________________________
atomic_TClass_ptr TPythia8::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TPythia8::Class_Name()
{
   return "TPythia8";
}

//______________________________________________________________________________
const char *TPythia8::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TPythia8*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TPythia8::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TPythia8*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TPythia8::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TPythia8*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TPythia8::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TPythia8*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
atomic_TClass_ptr TPythia8Decayer::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TPythia8Decayer::Class_Name()
{
   return "TPythia8Decayer";
}

//______________________________________________________________________________
const char *TPythia8Decayer::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TPythia8Decayer*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TPythia8Decayer::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TPythia8Decayer*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TPythia8Decayer::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TPythia8Decayer*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TPythia8Decayer::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TPythia8Decayer*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
void TPythia8::Streamer(TBuffer &R__b)
{
   // Stream an object of class TPythia8.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TPythia8::Class(),this);
   } else {
      R__b.WriteClassBuffer(TPythia8::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TPythia8(void *p) {
      return  p ? new(p) ::TPythia8 : new ::TPythia8;
   }
   static void *newArray_TPythia8(Long_t nElements, void *p) {
      return p ? new(p) ::TPythia8[nElements] : new ::TPythia8[nElements];
   }
   // Wrapper around operator delete
   static void delete_TPythia8(void *p) {
      delete (static_cast<::TPythia8*>(p));
   }
   static void deleteArray_TPythia8(void *p) {
      delete [] (static_cast<::TPythia8*>(p));
   }
   static void destruct_TPythia8(void *p) {
      typedef ::TPythia8 current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TPythia8

//______________________________________________________________________________
void TPythia8Decayer::Streamer(TBuffer &R__b)
{
   // Stream an object of class TPythia8Decayer.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TPythia8Decayer::Class(),this);
   } else {
      R__b.WriteClassBuffer(TPythia8Decayer::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TPythia8Decayer(void *p) {
      return  p ? new(p) ::TPythia8Decayer : new ::TPythia8Decayer;
   }
   static void *newArray_TPythia8Decayer(Long_t nElements, void *p) {
      return p ? new(p) ::TPythia8Decayer[nElements] : new ::TPythia8Decayer[nElements];
   }
   // Wrapper around operator delete
   static void delete_TPythia8Decayer(void *p) {
      delete (static_cast<::TPythia8Decayer*>(p));
   }
   static void deleteArray_TPythia8Decayer(void *p) {
      delete [] (static_cast<::TPythia8Decayer*>(p));
   }
   static void destruct_TPythia8Decayer(void *p) {
      typedef ::TPythia8Decayer current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TPythia8Decayer

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libEGPythia8() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libEGPythia8) = RecordReadRules_libEGPythia8();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libEGPythia8));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libEGPythia8_Impl() {
    static const char* headers[] = {
"TPythia8.h",
"TPythia8Decayer.h",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = R"DICTFWDDCLS(
#line 1 "libEGPythia8 dictionary forward declarations' payload"

#pragma diagnostic push
#pragma clang diagnostic ignored "-Wkeyword-compat"
#pragma clang diagnostic ignored "-Wignored-attributes"
#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
extern int __Cling_AutoLoading_Map;
class  __attribute__((annotate("$clingAutoload$TPythia8.h")))  TPythia8;
class  __attribute__((annotate("$clingAutoload$TPythia8Decayer.h")))  TPythia8Decayer;
#pragma diagnostic pop
)DICTFWDDCLS";
    static const char* payloadCode = R"DICTPAYLOAD(
#line 1 "libEGPythia8 dictionary payload"

#ifndef ROOT_SUPPORT_CLAD
  #define ROOT_SUPPORT_CLAD 1
#endif
#ifndef R__DUMMY_CXX_STANDARD_17
  #define R__DUMMY_CXX_STANDARD_17 1
#endif

#define _BACKWARD_BACKWARD_WARNING_H
// Inline headers
#include "TPythia8.h"
#include "TPythia8Decayer.h"

#undef  _BACKWARD_BACKWARD_WARNING_H
)DICTPAYLOAD";
    static const char* classesHeaders[] = {
"TPythia8", payloadCode, "@",
"TPythia8Decayer", payloadCode, "@",
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libEGPythia8",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libEGPythia8_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libEGPythia8_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libEGPythia8() {
  TriggerDictionaryInitialization_libEGPythia8_Impl();
}
